@@ -17,6 +17,7 @@ describe 'octavia::api' do
       :healthcheck_enabled            => true,
       :healthcheck_refresh_interval   => 5,
       :allow_ping_health_monitors     => true,
+      :allow_prometheus_listeners     => true,
     }
   end
 
@@ -67,6 +68,7 @@ describe 'octavia::api' do
         is_expected.to contain_octavia_config('api_settings/default_pool_tls_versions').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_octavia_config('api_settings/minimum_tls_version').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_octavia_config('api_settings/allow_ping_health_monitors').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_octavia_config('api_settings/allow_prometheus_listeners').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_oslo__middleware('octavia_config').with(
           :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
         )
@@ -89,6 +91,7 @@ describe 'octavia::api' do
       is_expected.to contain_octavia_config('api_settings/healthcheck_enabled').with_value( params[:healthcheck_enabled] )
       is_expected.to contain_octavia_config('api_settings/healthcheck_refresh_interval').with_value( params[:healthcheck_refresh_interval] )
       is_expected.to contain_octavia_config('api_settings/allow_ping_health_monitors').with_value( params[:allow_ping_health_monitors] )
+      is_expected.to contain_octavia_config('api_settings/allow_prometheus_listeners').with_value( params[:allow_prometheus_listeners] )
     end
 
     [{:enabled => true}, {:enabled => false}].each do |param_hash|
@@ -267,7 +270,7 @@ describe 'octavia::api' do
         facts.merge!(OSDefaults.get_facts())
       end
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :api_package_name => 'octavia-api',
             :api_service_name => 'octavia-api' }
