@@ -35,19 +35,23 @@ describe 'octavia' do
           :control_exchange          => '<SERVICE DEFAULT>',
         )
         should contain_oslo__messaging__rabbit('octavia_config').with(
-          :rabbit_ha_queues            => '<SERVICE DEFAULT>',
-          :heartbeat_timeout_threshold => '<SERVICE DEFAULT>',
-          :heartbeat_rate              => '<SERVICE DEFAULT>',
-          :heartbeat_in_pthread        => '<SERVICE DEFAULT>',
-          :rabbit_use_ssl              => '<SERVICE DEFAULT>',
-          :kombu_reconnect_delay       => '<SERVICE DEFAULT>',
-          :kombu_failover_strategy     => '<SERVICE DEFAULT>',
-          :kombu_ssl_version           => '<SERVICE DEFAULT>',
-          :kombu_ssl_keyfile           => '<SERVICE DEFAULT>',
-          :kombu_ssl_certfile          => '<SERVICE DEFAULT>',
-          :kombu_ssl_ca_certs          => '<SERVICE DEFAULT>',
-          :kombu_compression           => '<SERVICE DEFAULT>',
-          :amqp_durable_queues         => '<SERVICE DEFAULT>',
+          :rabbit_ha_queues                => '<SERVICE DEFAULT>',
+          :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
+          :heartbeat_rate                  => '<SERVICE DEFAULT>',
+          :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
+          :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
+          :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
+          :kombu_failover_strategy         => '<SERVICE DEFAULT>',
+          :kombu_ssl_version               => '<SERVICE DEFAULT>',
+          :kombu_ssl_keyfile               => '<SERVICE DEFAULT>',
+          :kombu_ssl_certfile              => '<SERVICE DEFAULT>',
+          :kombu_ssl_ca_certs              => '<SERVICE DEFAULT>',
+          :kombu_compression               => '<SERVICE DEFAULT>',
+          :amqp_durable_queues             => '<SERVICE DEFAULT>',
+          :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
+          :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
+          :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
+          :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
         )
         is_expected.to contain_oslo__messaging__amqp('octavia_config').with(
           :server_request_prefix => '<SERVICE DEFAULT>',
@@ -88,6 +92,10 @@ describe 'octavia' do
           :rabbit_heartbeat_timeout_threshold => '60',
           :rabbit_heartbeat_rate              => '10',
           :rabbit_heartbeat_in_pthread        => true,
+          :rabbit_quorum_queue                => true,
+          :rabbit_quorum_delivery_limit       => 3,
+          :rabbit_quorum_max_memory_length    => 5,
+          :rabbit_quorum_max_memory_bytes     => 1073741824,
           :kombu_compression                  => 'gzip',
           :kombu_reconnect_delay              => '5.0',
           :kombu_failover_strategy            => 'shuffle',
@@ -108,19 +116,23 @@ describe 'octavia' do
           :control_exchange          => 'octavia',
         )
         should contain_oslo__messaging__rabbit('octavia_config').with(
-          :rabbit_ha_queues            => true,
-          :heartbeat_timeout_threshold => '60',
-          :heartbeat_rate              => '10',
-          :heartbeat_in_pthread        => true,
-          :rabbit_use_ssl              => '<SERVICE DEFAULT>',
-          :kombu_reconnect_delay       => '5.0',
-          :kombu_failover_strategy     => 'shuffle',
-          :kombu_ssl_version           => '<SERVICE DEFAULT>',
-          :kombu_ssl_keyfile           => '<SERVICE DEFAULT>',
-          :kombu_ssl_certfile          => '<SERVICE DEFAULT>',
-          :kombu_ssl_ca_certs          => '<SERVICE DEFAULT>',
-          :kombu_compression           => 'gzip',
-          :amqp_durable_queues         => true,
+          :rabbit_ha_queues                => true,
+          :heartbeat_timeout_threshold     => '60',
+          :heartbeat_rate                  => '10',
+          :heartbeat_in_pthread            => true,
+          :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
+          :kombu_reconnect_delay           => '5.0',
+          :kombu_failover_strategy         => 'shuffle',
+          :kombu_ssl_version               => '<SERVICE DEFAULT>',
+          :kombu_ssl_keyfile               => '<SERVICE DEFAULT>',
+          :kombu_ssl_certfile              => '<SERVICE DEFAULT>',
+          :kombu_ssl_ca_certs              => '<SERVICE DEFAULT>',
+          :kombu_compression               => 'gzip',
+          :amqp_durable_queues             => true,
+          :rabbit_quorum_queue             => true,
+          :rabbit_quorum_delivery_limit    => 3,
+          :rabbit_quorum_max_memory_length => 5,
+          :rabbit_quorum_max_memory_bytes  => 1073741824,
         )
         should contain_oslo__messaging__notifications('octavia_config').with(
           :transport_url => 'rabbit://rabbit_user:password@localhost:5673',
